@@ -2,14 +2,14 @@ import inspect
 
 from discord.ext import commands
 
-from . import utils
+from . import utils as vbu
 
 
-class SlashCommandContext(utils.interactions.interaction_messageable.InteractionMessageable, utils.Context):
+class SlashCommandContext(vbu.interactions.interaction_messageable.InteractionMessageable, vbu.Context):
     pass
 
 
-class InteractionHandler(utils.Cog):
+class InteractionHandler(vbu.Cog):
 
     async def get_context_from_interaction(self, payload, *, cls=SlashCommandContext):
         """
@@ -33,7 +33,11 @@ class InteractionHandler(utils.Cog):
         # Put our options in a dict
         given_values = {}
         for i in options:
-            given_values[i['name']] = i['value']
+            value = str(i['value'])
+            # if isinstance(value, str):
+            given_values[i['name']] = value.strip()
+            # else:
+            #     given_values[i['name']] = value
 
         # If we have a target_id, then the interaction is a context menu
         if 'target_id' in payload['data']:
@@ -49,7 +53,7 @@ class InteractionHandler(utils.Cog):
         channel, _ = state._get_guild_channel(payload)
 
         # Make our fake message
-        fake_message = utils.interactions.InteractionMessage(
+        fake_message = vbu.interactions.InteractionMessage(
             channel=channel,
             state=state,
             data=payload,
@@ -66,14 +70,20 @@ class InteractionHandler(utils.Cog):
         # Make it work
         ctx.invoked_with = invoker
         ctx.command = self.bot.get_command(command_name)
+        if ctx.command is None and 'target_id' in payload['data']:
+            for i in self.bot.walk_commands():
+                if getattr(i, "context_command_name", None) == command_name:
+                    ctx.command = i
+                    break
         ctx.command_name = command_name
         ctx.given_values = given_values
+        ctx.is_interaction = True
 
         # Return context
         self.logger.debug("Returning context object")
         return ctx
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_socket_response(self, payload: dict):
         """
         Process any interaction create payloads we may receive.
@@ -109,7 +119,11 @@ class InteractionHandler(utils.Cog):
                 else:
                     sig = ctx.command.clean_params[name]
                 converter = ctx.command._get_converter(sig)
-                v = await ctx.command.do_conversion(ctx, converter, value, sig)
+                try:
+                    v = await ctx.command.do_conversion(ctx, converter, value, sig)
+                except commands.CommandError as exc:
+                    await ctx.command.dispatch_error(ctx, exc)
+                    return
                 if sig.kind in [inspect.Parameter.POSITIONAL_ONLY, inspect.Parameter.POSITIONAL_OR_KEYWORD]:
                     positional_converted.append(v)
                 else:
@@ -117,7 +131,7 @@ class InteractionHandler(utils.Cog):
 
             # And invoke
             self.logger.debug("Invoking interaction context for command %s" % (ctx.command.name))
-            self.bot.dispatch('command', ctx)
+            self.bot.dispatch("command", ctx)
             try:
                 if await self.bot.can_run(ctx):
                     if await ctx.command.can_run(ctx):
@@ -127,13 +141,13 @@ class InteractionHandler(utils.Cog):
             except commands.CommandError as exc:
                 await ctx.command.dispatch_error(ctx, exc)
             else:
-                self.bot.dispatch('command_completion', ctx)
+                self.bot.dispatch("command_completion", ctx)
 
         # See if it was a clicked component
         elif payload['d']['type'] == 3:
-            clicked_button_payload = utils.interactions.components.ComponentInteractionPayload.from_payload(
+            clicked_button_payload = vbu.interactions.components.ComponentInteractionPayload.from_payload(
                 payload['d'], self.bot._connection,
-            )
+            )  # TODO should this be a webhook connection state?
             # clicked_button_payload._send_interaction_response_callback()
             self.bot.dispatch("button_click", clicked_button_payload)  # DEPRECATED PLEASE DO NOT USE
             self.bot.dispatch("component_interaction", clicked_button_payload)
@@ -144,6 +158,6 @@ class InteractionHandler(utils.Cog):
             self.logger.warning("Invalid interaction type received - %d" % (payload['d']['type']))
 
 
-def setup(bot: utils.Bot):
+def setup(bot: vbu.Bot):
     x = InteractionHandler(bot)
     bot.add_cog(x)
