@@ -24,6 +24,7 @@ from .redis import RedisConnection
 from .statsd import StatsdConnection
 from .analytics_log_handler import AnalyticsLogHandler, AnalyticsClientSession
 from .interactions.components import MessageComponents
+from .interactions.interaction_messageable import InteractionMessageable
 from .models import ComponentMessage, ComponentWebhookMessage
 from .shard_manager import ShardManagerClient
 from . import interactions
@@ -87,6 +88,15 @@ class RouteV8(discord.http.Route):
     BASE = 'https://discord.com/api/v8'
 
 
+class _EmptyProxy(object):
+
+    def __bool__(self):
+        return False
+
+
+_empty = _EmptyProxy()
+
+
 class MinimalBot(commands.AutoShardedBot):
     """
     A minimal version of the VoxelBotUtils bot that inherits from :class:`discord.ext.commands.AutoShardedBot`
@@ -400,15 +410,15 @@ class MinimalBot(commands.AutoShardedBot):
         return content, embed
 
     async def _send_button_message(
-            self, messageable, content: str = None, *, tts: bool = False,
-            embed: discord.Embed = None, file: discord.File = None,
-            files: typing.List[discord.File] = None, delete_after: float = None,
-            nonce: str = None, allowed_mentions: discord.AllowedMentions = None,
-            reference: discord.MessageReference = None, mention_author: bool = None,
-            components: MessageComponents = None,
+            self, messageable, content: str = _empty, *, tts: bool = False,
+            embed: discord.Embed = _empty, file: discord.File = _empty,
+            files: typing.List[discord.File] = _empty, delete_after: float = _empty,
+            nonce: str = _empty, allowed_mentions: discord.AllowedMentions = _empty,
+            reference: discord.MessageReference = _empty, mention_author: bool = _empty,
+            components: MessageComponents = _empty,
             ephemeral: bool = False, embeddify: bool = None,
-            image_url: bool = None, embeddify_file: bool = True,
-            wait: bool = True, embeds: typing.List[discord.Embed] = None,
+            image_url: bool = _empty, embeddify_file: bool = True,
+            wait: bool = True, embeds: typing.List[discord.Embed] = _empty,
             _no_wait_response_type: int = 4):
         """
         An alternative send method so that we can add components to messages.
@@ -418,10 +428,6 @@ class MinimalBot(commands.AutoShardedBot):
 
         # Work out where we want to send to
         channel = await messageable._get_channel()
-        content, embed = self.get_context_message(
-            messageable, content=content, embed=embed, file=file, embeddify=embeddify,
-            image_url=image_url, embeddify_file=embeddify_file,
-        )
         try:
             state = messageable._state
         except AttributeError:
@@ -430,19 +436,31 @@ class MinimalBot(commands.AutoShardedBot):
         await lock.acquire()
 
         # Work out the main content
-        content = str(content) if content is not None else None
-        if embed is not None and embeds is not None:
+        content, embed = self.get_context_message(
+            messageable, content=content, embed=embed, file=file, embeddify=embeddify,
+            image_url=image_url, embeddify_file=embeddify_file,
+        )
+        content = str(content) if content not in [None, _empty] else content
+
+        # Make sure they didn't dupe the fields
+        if embed not in [None, _empty] and embeds not in [None, _empty]:
             raise discord.InvalidArgument('cannot pass both embed and embeds parameter to send()')
-        if embed is not None:
+
+        # Check embed (singular)
+        if embed not in [None, _empty]:  # Explicit check because embeds can be falsy
             embeds = [embed]
-            embed = None
+            embed = None  # Not used elsewhere but let's reset it here anyway
+
+        # Check embeds (multiple)
         if embeds and len(embeds) > 10:
             raise discord.InvalidArgument('embeds parameter must be a list of up to 10 elements')
         if embeds:
             embeds = [e.to_dict() for e in embeds]
+        elif embed is None:
+            embeds = []
 
         # Work out our allowed mentions
-        if allowed_mentions is not None:
+        if allowed_mentions not in [None, _empty]:
             if state.allowed_mentions is not None:
                 allowed_mentions = state.allowed_mentions.merge(allowed_mentions).to_dict()
             else:
@@ -451,17 +469,17 @@ class MinimalBot(commands.AutoShardedBot):
             allowed_mentions = state.allowed_mentions and state.allowed_mentions.to_dict()
 
         # Work out our message references
-        if mention_author is not None:
+        if mention_author not in [None, _empty]:
             allowed_mentions = allowed_mentions or discord.AllowedMentions().to_dict()
             allowed_mentions['replied_user'] = bool(mention_author)
-        if reference is not None:
+        if reference not in [None, _empty]:
             try:
                 reference = reference.to_message_reference_dict()
             except AttributeError:
                 raise discord.InvalidArgument('reference parameter must be Message or MessageReference') from None
 
         # Make sure the files are valid
-        if file is not None and files is not None:
+        if file not in [None, _empty] and files not in [None, _empty]:
             raise discord.InvalidArgument('cannot pass both file and files parameter to send()')
         if file:
             files = [file]
@@ -471,7 +489,7 @@ class MinimalBot(commands.AutoShardedBot):
             raise discord.InvalidArgument('files parameter must be a list of File')
 
         # Fix up the components
-        if components:
+        if components not in [None, _empty]:
             if not isinstance(components, MessageComponents):
                 raise TypeError(f"Components kwarg must be of type {MessageComponents}")
             components = components.to_dict()
@@ -505,27 +523,30 @@ class MinimalBot(commands.AutoShardedBot):
 
         # Build a payload to send
         payload = {}
-        if content:
+        if content is not _empty:
             payload['content'] = content
         if tts:
             payload['tts'] = True
-        if embeds:
+        if embeds is not _empty:
             payload['embeds'] = embeds
-        if nonce:
+        if nonce is not _empty:
             payload['nonce'] = nonce
-        if allowed_mentions:
+        if allowed_mentions is not _empty:
             payload['allowed_mentions'] = allowed_mentions
-        if reference:
+        if reference is not _empty:
             payload['message_reference'] = reference
-        if components:
-            payload['components'] = components
+        if components is not _empty:
+            if components is None:
+                payload['components'] = list()
+            else:
+                payload['components'] = components
         if ephemeral:
             if not getattr(messageable, "CAN_SEND_EPHEMERAL", False):
                 raise ValueError("Cannot send ephemeral messages with type {0.__class__}".format(messageable))
             payload['flags'] = discord.message.MessageFlags(ephemeral=True).value
 
         # Send the HTTP requests, including files
-        if files is not None:
+        if files not in [None, _empty]:
             form = []
             form.append({'name': 'payload_json', 'value': discord.utils.to_json(payload)})
             try:
@@ -580,7 +601,7 @@ class MinimalBot(commands.AutoShardedBot):
             ret = ComponentMessage(state=state, channel=channel, data=response_data)
 
         # See if we want to delete the message
-        if delete_after is not None:
+        if delete_after not in [None, _empty]:
             await ret.delete(delay=delete_after)
 
         # Return the created message
@@ -646,9 +667,6 @@ class MinimalBot(commands.AutoShardedBot):
             flags.suppress_embeds = suppress
             fields['flags'] = flags.value
 
-        # See if we should delete the message
-        delete_after = fields.pop('delete_after', None)
-
         # Make the allowed mentions
         try:
             allowed_mentions = fields.pop('allowed_mentions')
@@ -671,6 +689,8 @@ class MinimalBot(commands.AutoShardedBot):
         else:
             fields['attachments'] = [a.to_dict() for a in attachments]
 
+        delete_after = fields.pop('delete_after', None)
+
         # Edit the message
         if fields:
             if isinstance(message, discord.WebhookMessage):
@@ -1375,8 +1395,8 @@ class Bot(MinimalBot):
         return await super().invoke(ctx)
 
     def get_context_message(
-            self, messageable, content: str, *, embed: discord.Embed = None,
-            file: discord.File = None, embeddify: bool = None,
+            self, messageable, content: str, *, embed: discord.Embed = _empty,
+            file: discord.File = _empty, embeddify: bool = None,
             image_url: str = None, embeddify_file: bool = True,
             **kwargs) -> typing.Tuple[str, discord.Embed]:
         """
@@ -1384,14 +1404,25 @@ class Bot(MinimalBot):
         into a messageable object.
         """
 
-        if embeddify is None and image_url is not None:
+        # We got an embed? Let's go
+        if embed:
+            return content, embed
+
+        # If an image url is set, auto-set embeddify
+        if embeddify is None and image_url not in [None, _empty]:
             embeddify = True
-        if embeddify is None:
+
+        # If embeddify isn't set, grab from the config
+        elif embeddify is None:
             embeddify = self.embeddify
 
-        # See if we need to check channel permissions at all
-        if embeddify is False or embed is not None:
-            should_not_embed = True
+        # See if we're done now
+        if embeddify is False:
+            return content, embed
+
+        # Check the channel permissions
+        if isinstance(messageable, InteractionMessageable):
+            missing_embed_permission = False
         else:
             try:
                 try:
@@ -1402,14 +1433,16 @@ class Bot(MinimalBot):
                 missing_embed_permission = not discord.Permissions(embed_links=True).is_subset(channel_permissions)
             except AttributeError:
                 missing_embed_permission = False
-            should_not_embed = any([
-                missing_embed_permission,
-                embeddify is False,
-                embed is not None,
-            ])
 
-        # Can't embed? Just send it normally
-        if should_not_embed:
+        # Collate our content and see if we're ABLE to send embeds
+        should_not_embed = any((
+            missing_embed_permission,
+            embeddify is False,
+            embed not in [None, _empty],
+        ))
+
+        # Can't embed or have no content? Just send it normally
+        if should_not_embed or content in [None, _empty]:
             return content, embed
 
         # No current embed, and we _want_ to embed it? Alright!
@@ -1420,7 +1453,7 @@ class Bot(MinimalBot):
         self.set_footer_from_config(embed)
 
         # Set image
-        if image_url is not None:
+        if image_url not in [None, _empty]:
             embed.set_image(url=image_url)
         if file and file.filename and embeddify_file:
             file_is_image = any([
