@@ -32,7 +32,7 @@ class Converter(object):
         Args:
             prompt (str): The message that should be sent to the user when asking for the convertable.
             checks (typing.List[voxelbotutils.menus.Check]): A list of check objects that should be used to make sure the user's
-                input is valid. These will be silently ignored if a :param:`components` parameter is passed.
+                input is valid. These will be silently ignored if a :code:`components` parameter is passed.
             converter (typing.Union[typing.Callable[[str], typing.Any], commands.Converter]): A callable that
                 will be used to convert the user's input. If a converter fails then :code:`None` will be returned,
                 so use the given checks to make sure that this does not happen if this behaviour is undesirable.
