@@ -1,4 +1,4 @@
-web_config_file = """
+web_config_file = r"""
 website_base_url = "http://localhost:8080"  # This will be used to dynamically make the redirect url internally
 login_url = "/login"  # The url or route used to prompt the user to login
 routes = [ "frontend", "backend", ]  # These routes `/website/<filename>` will have their `routes` variable imported which will be loaded into the bot's route table
@@ -8,7 +8,7 @@ oauth_scopes = [ "identify", "guilds", ]  # The scopes that should be added to t
 # Config files are loaded as `config/<filename>`
 # This is fully welcome to be entirely empty
 [discord_bot_configs]
-    bot = "config.toml"
+    # bot = "config.toml"
 
 # Used for the bot's invite and login links
 [oauth]
